==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/refactoring.java/src/org/netbeans/modules/refactoring/java/spi/JavaWhereUsedFilters.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2012 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2012 Sun Microsystems, Inc.
 */
package org.netbeans.modules.refactoring.java.spi;

/**
 * Filters used by Java Find Usages plugins.
 * 
 * @author Ralph Benjamin Ruijs <ralphbenjamin@netbeans.org>
 * @since 1.39
 */
public enum JavaWhereUsedFilters {

    IMPORT("filter-import"),
    COMMENT("filter-comment"),
    TESTFILE("filter-testfile");
    private final String key;

    private JavaWhereUsedFilters(String key) {
        this.key = key;
    }

    public String getKey() {
        return key;
    }

    public static enum ReadWrite {

        READ("filter-read"),
        WRITE("filter-write"),
        READ_WRITE("filter-readwrite");
        private final String key;

        private ReadWrite(String key) {
            this.key = key;
        }

        public String getKey() {
            return key;
        }
    }
}

==> netbeans_8.1+dfsg3.orig.tar.xz: netbeans-8.1/refactoring.java/src/org/netbeans/modules/refactoring/java/spi/JavaWhereUsedFilters.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2012 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2012 Sun Microsystems, Inc.
 */
package org.netbeans.modules.refactoring.java.spi;

/**
 * Filters used by Java Find Usages plugins.
 * 
 * @author Ralph Benjamin Ruijs <ralphbenjamin@netbeans.org>
 * @since 1.39
 */
public enum JavaWhereUsedFilters {

    IMPORT("filter-import"),
    COMMENT("filter-comment"),
    TESTFILE("filter-testfile"),
    /**
     * @since 1.54
     */
    SOURCEFILE("filter-sourcefile"),
    /**
     * @since 1.55
     */
    BINARYFILE("filter-binaryfile"),
    /**
     * @since 1.55
     */
    DEPENDENCY("filter-dependencyfile"),
    /**
     * @since 1.55
     */
    PLATFORM("filter-platformfile");
    private final String key;

    private JavaWhereUsedFilters(String key) {
        this.key = key;
    }

    public String getKey() {
        return key;
    }

    public static enum ReadWrite {

        READ("filter-read"),
        WRITE("filter-write"),
        READ_WRITE("filter-readwrite");
        private final String key;

        private ReadWrite(String key) {
            this.key = key;
        }

        public String getKey() {
            return key;
        }
    }
}
